@@ -1,5 +1,5 @@
 /**
-\file version.hpp
+\file
 \copyright Copyright 2020. Tom de Geus. All rights reserved.
 \license This project is released under the MIT License.
 */
